/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface EndpointsServiceConfig extends cdktf.TerraformMetaArguments {
    /**
    * The full text of the Service Config YAML file (Example located here). If provided, must also provide protoc_output_base64. open_api config must not be provided.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.21.0/docs/resources/endpoints_service#grpc_config EndpointsService#grpc_config}
    */
    readonly grpcConfig?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.21.0/docs/resources/endpoints_service#id EndpointsService#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The full text of the OpenAPI YAML configuration as described here. Either this, or both of grpc_config and protoc_output_base64 must be specified.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.21.0/docs/resources/endpoints_service#openapi_config EndpointsService#openapi_config}
    */
    readonly openapiConfig?: string;
    /**
    * The project ID that the service belongs to. If not provided, provider project is used.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.21.0/docs/resources/endpoints_service#project EndpointsService#project}
    */
    readonly project?: string;
    /**
    * The full contents of the Service Descriptor File generated by protoc. This should be a compiled .pb file, base64-encoded.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.21.0/docs/resources/endpoints_service#protoc_output_base64 EndpointsService#protoc_output_base64}
    */
    readonly protocOutputBase64?: string;
    /**
    * The name of the service. Usually of the form $apiname.endpoints.$projectid.cloud.goog.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.21.0/docs/resources/endpoints_service#service_name EndpointsService#service_name}
    */
    readonly serviceName: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.21.0/docs/resources/endpoints_service#timeouts EndpointsService#timeouts}
    */
    readonly timeouts?: EndpointsServiceTimeouts;
}
export interface EndpointsServiceApisMethods {
}
export declare function endpointsServiceApisMethodsToTerraform(struct?: EndpointsServiceApisMethods): any;
export declare function endpointsServiceApisMethodsToHclTerraform(struct?: EndpointsServiceApisMethods): any;
export declare class EndpointsServiceApisMethodsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): EndpointsServiceApisMethods | undefined;
    set internalValue(value: EndpointsServiceApisMethods | undefined);
    get name(): string;
    get requestType(): string;
    get responseType(): string;
    get syntax(): string;
}
export declare class EndpointsServiceApisMethodsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): EndpointsServiceApisMethodsOutputReference;
}
export interface EndpointsServiceApis {
}
export declare function endpointsServiceApisToTerraform(struct?: EndpointsServiceApis): any;
export declare function endpointsServiceApisToHclTerraform(struct?: EndpointsServiceApis): any;
export declare class EndpointsServiceApisOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): EndpointsServiceApis | undefined;
    set internalValue(value: EndpointsServiceApis | undefined);
    private _methods;
    get methods(): EndpointsServiceApisMethodsList;
    get name(): string;
    get syntax(): string;
    get version(): string;
}
export declare class EndpointsServiceApisList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): EndpointsServiceApisOutputReference;
}
export interface EndpointsServiceEndpoints {
}
export declare function endpointsServiceEndpointsToTerraform(struct?: EndpointsServiceEndpoints): any;
export declare function endpointsServiceEndpointsToHclTerraform(struct?: EndpointsServiceEndpoints): any;
export declare class EndpointsServiceEndpointsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): EndpointsServiceEndpoints | undefined;
    set internalValue(value: EndpointsServiceEndpoints | undefined);
    get address(): string;
    get name(): string;
}
export declare class EndpointsServiceEndpointsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): EndpointsServiceEndpointsOutputReference;
}
export interface EndpointsServiceTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.21.0/docs/resources/endpoints_service#create EndpointsService#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.21.0/docs/resources/endpoints_service#delete EndpointsService#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.21.0/docs/resources/endpoints_service#update EndpointsService#update}
    */
    readonly update?: string;
}
export declare function endpointsServiceTimeoutsToTerraform(struct?: EndpointsServiceTimeouts | cdktf.IResolvable): any;
export declare function endpointsServiceTimeoutsToHclTerraform(struct?: EndpointsServiceTimeouts | cdktf.IResolvable): any;
export declare class EndpointsServiceTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): EndpointsServiceTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: EndpointsServiceTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google/5.21.0/docs/resources/endpoints_service google_endpoints_service}
*/
export declare class EndpointsService extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_endpoints_service";
    /**
    * Generates CDKTF code for importing a EndpointsService resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the EndpointsService to import
    * @param importFromId The id of the existing EndpointsService that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google/5.21.0/docs/resources/endpoints_service#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the EndpointsService to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google/5.21.0/docs/resources/endpoints_service google_endpoints_service} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options EndpointsServiceConfig
    */
    constructor(scope: Construct, id: string, config: EndpointsServiceConfig);
    private _apis;
    get apis(): EndpointsServiceApisList;
    get configId(): string;
    get dnsAddress(): string;
    private _endpoints;
    get endpoints(): EndpointsServiceEndpointsList;
    private _grpcConfig?;
    get grpcConfig(): string;
    set grpcConfig(value: string);
    resetGrpcConfig(): void;
    get grpcConfigInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _openapiConfig?;
    get openapiConfig(): string;
    set openapiConfig(value: string);
    resetOpenapiConfig(): void;
    get openapiConfigInput(): string | undefined;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _protocOutputBase64?;
    get protocOutputBase64(): string;
    set protocOutputBase64(value: string);
    resetProtocOutputBase64(): void;
    get protocOutputBase64Input(): string | undefined;
    private _serviceName?;
    get serviceName(): string;
    set serviceName(value: string);
    get serviceNameInput(): string | undefined;
    private _timeouts;
    get timeouts(): EndpointsServiceTimeoutsOutputReference;
    putTimeouts(value: EndpointsServiceTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | EndpointsServiceTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
