/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface HealthcareDatasetIamMemberConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.21.0/docs/resources/healthcare_dataset_iam_member#dataset_id HealthcareDatasetIamMember#dataset_id}
    */
    readonly datasetId: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.21.0/docs/resources/healthcare_dataset_iam_member#id HealthcareDatasetIamMember#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.21.0/docs/resources/healthcare_dataset_iam_member#member HealthcareDatasetIamMember#member}
    */
    readonly member: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.21.0/docs/resources/healthcare_dataset_iam_member#role HealthcareDatasetIamMember#role}
    */
    readonly role: string;
    /**
    * condition block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.21.0/docs/resources/healthcare_dataset_iam_member#condition HealthcareDatasetIamMember#condition}
    */
    readonly condition?: HealthcareDatasetIamMemberCondition;
}
export interface HealthcareDatasetIamMemberCondition {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.21.0/docs/resources/healthcare_dataset_iam_member#description HealthcareDatasetIamMember#description}
    */
    readonly description?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.21.0/docs/resources/healthcare_dataset_iam_member#expression HealthcareDatasetIamMember#expression}
    */
    readonly expression: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.21.0/docs/resources/healthcare_dataset_iam_member#title HealthcareDatasetIamMember#title}
    */
    readonly title: string;
}
export declare function healthcareDatasetIamMemberConditionToTerraform(struct?: HealthcareDatasetIamMemberConditionOutputReference | HealthcareDatasetIamMemberCondition): any;
export declare function healthcareDatasetIamMemberConditionToHclTerraform(struct?: HealthcareDatasetIamMemberConditionOutputReference | HealthcareDatasetIamMemberCondition): any;
export declare class HealthcareDatasetIamMemberConditionOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): HealthcareDatasetIamMemberCondition | undefined;
    set internalValue(value: HealthcareDatasetIamMemberCondition | undefined);
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _expression?;
    get expression(): string;
    set expression(value: string);
    get expressionInput(): string | undefined;
    private _title?;
    get title(): string;
    set title(value: string);
    get titleInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google/5.21.0/docs/resources/healthcare_dataset_iam_member google_healthcare_dataset_iam_member}
*/
export declare class HealthcareDatasetIamMember extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_healthcare_dataset_iam_member";
    /**
    * Generates CDKTF code for importing a HealthcareDatasetIamMember resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the HealthcareDatasetIamMember to import
    * @param importFromId The id of the existing HealthcareDatasetIamMember that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google/5.21.0/docs/resources/healthcare_dataset_iam_member#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the HealthcareDatasetIamMember to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google/5.21.0/docs/resources/healthcare_dataset_iam_member google_healthcare_dataset_iam_member} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options HealthcareDatasetIamMemberConfig
    */
    constructor(scope: Construct, id: string, config: HealthcareDatasetIamMemberConfig);
    private _datasetId?;
    get datasetId(): string;
    set datasetId(value: string);
    get datasetIdInput(): string | undefined;
    get etag(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _member?;
    get member(): string;
    set member(value: string);
    get memberInput(): string | undefined;
    private _role?;
    get role(): string;
    set role(value: string);
    get roleInput(): string | undefined;
    private _condition;
    get condition(): HealthcareDatasetIamMemberConditionOutputReference;
    putCondition(value: HealthcareDatasetIamMemberCondition): void;
    resetCondition(): void;
    get conditionInput(): HealthcareDatasetIamMemberCondition | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
