/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface NetworkConnectivityServiceConnectionPolicyConfig extends cdktf.TerraformMetaArguments {
    /**
    * Free-text description of the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.21.0/docs/resources/network_connectivity_service_connection_policy#description NetworkConnectivityServiceConnectionPolicy#description}
    */
    readonly description?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.21.0/docs/resources/network_connectivity_service_connection_policy#id NetworkConnectivityServiceConnectionPolicy#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * User-defined labels.
    *
    *
    * **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
    * Please refer to the field 'effective_labels' for all of the labels present on the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.21.0/docs/resources/network_connectivity_service_connection_policy#labels NetworkConnectivityServiceConnectionPolicy#labels}
    */
    readonly labels?: {
        [key: string]: string;
    };
    /**
    * The location of the ServiceConnectionPolicy.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.21.0/docs/resources/network_connectivity_service_connection_policy#location NetworkConnectivityServiceConnectionPolicy#location}
    */
    readonly location: string;
    /**
    * The name of a ServiceConnectionPolicy. Format: projects/{project}/locations/{location}/serviceConnectionPolicies/{service_connection_policy} See: https://google.aip.dev/122#fields-representing-resource-names
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.21.0/docs/resources/network_connectivity_service_connection_policy#name NetworkConnectivityServiceConnectionPolicy#name}
    */
    readonly name: string;
    /**
    * The resource path of the consumer network. Example: - projects/{projectNumOrId}/global/networks/{resourceId}.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.21.0/docs/resources/network_connectivity_service_connection_policy#network NetworkConnectivityServiceConnectionPolicy#network}
    */
    readonly network: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.21.0/docs/resources/network_connectivity_service_connection_policy#project NetworkConnectivityServiceConnectionPolicy#project}
    */
    readonly project?: string;
    /**
    * The service class identifier for which this ServiceConnectionPolicy is for. The service class identifier is a unique, symbolic representation of a ServiceClass.
    * It is provided by the Service Producer. Google services have a prefix of gcp. For example, gcp-cloud-sql. 3rd party services do not. For example, test-service-a3dfcx.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.21.0/docs/resources/network_connectivity_service_connection_policy#service_class NetworkConnectivityServiceConnectionPolicy#service_class}
    */
    readonly serviceClass: string;
    /**
    * psc_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.21.0/docs/resources/network_connectivity_service_connection_policy#psc_config NetworkConnectivityServiceConnectionPolicy#psc_config}
    */
    readonly pscConfig?: NetworkConnectivityServiceConnectionPolicyPscConfig;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.21.0/docs/resources/network_connectivity_service_connection_policy#timeouts NetworkConnectivityServiceConnectionPolicy#timeouts}
    */
    readonly timeouts?: NetworkConnectivityServiceConnectionPolicyTimeouts;
}
export interface NetworkConnectivityServiceConnectionPolicyPscConnectionsError {
}
export declare function networkConnectivityServiceConnectionPolicyPscConnectionsErrorToTerraform(struct?: NetworkConnectivityServiceConnectionPolicyPscConnectionsError): any;
export declare function networkConnectivityServiceConnectionPolicyPscConnectionsErrorToHclTerraform(struct?: NetworkConnectivityServiceConnectionPolicyPscConnectionsError): any;
export declare class NetworkConnectivityServiceConnectionPolicyPscConnectionsErrorOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): NetworkConnectivityServiceConnectionPolicyPscConnectionsError | undefined;
    set internalValue(value: NetworkConnectivityServiceConnectionPolicyPscConnectionsError | undefined);
    get code(): number;
    private _details;
    get details(): cdktf.StringMapList;
    get message(): string;
}
export declare class NetworkConnectivityServiceConnectionPolicyPscConnectionsErrorList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): NetworkConnectivityServiceConnectionPolicyPscConnectionsErrorOutputReference;
}
export interface NetworkConnectivityServiceConnectionPolicyPscConnectionsErrorInfo {
}
export declare function networkConnectivityServiceConnectionPolicyPscConnectionsErrorInfoToTerraform(struct?: NetworkConnectivityServiceConnectionPolicyPscConnectionsErrorInfo): any;
export declare function networkConnectivityServiceConnectionPolicyPscConnectionsErrorInfoToHclTerraform(struct?: NetworkConnectivityServiceConnectionPolicyPscConnectionsErrorInfo): any;
export declare class NetworkConnectivityServiceConnectionPolicyPscConnectionsErrorInfoOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): NetworkConnectivityServiceConnectionPolicyPscConnectionsErrorInfo | undefined;
    set internalValue(value: NetworkConnectivityServiceConnectionPolicyPscConnectionsErrorInfo | undefined);
    get domain(): string;
    private _metadata;
    get metadata(): cdktf.StringMap;
    get reason(): string;
}
export declare class NetworkConnectivityServiceConnectionPolicyPscConnectionsErrorInfoList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): NetworkConnectivityServiceConnectionPolicyPscConnectionsErrorInfoOutputReference;
}
export interface NetworkConnectivityServiceConnectionPolicyPscConnections {
}
export declare function networkConnectivityServiceConnectionPolicyPscConnectionsToTerraform(struct?: NetworkConnectivityServiceConnectionPolicyPscConnections): any;
export declare function networkConnectivityServiceConnectionPolicyPscConnectionsToHclTerraform(struct?: NetworkConnectivityServiceConnectionPolicyPscConnections): any;
export declare class NetworkConnectivityServiceConnectionPolicyPscConnectionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): NetworkConnectivityServiceConnectionPolicyPscConnections | undefined;
    set internalValue(value: NetworkConnectivityServiceConnectionPolicyPscConnections | undefined);
    get consumerAddress(): string;
    get consumerForwardingRule(): string;
    get consumerTargetProject(): string;
    private _error;
    get error(): NetworkConnectivityServiceConnectionPolicyPscConnectionsErrorList;
    private _errorInfo;
    get errorInfo(): NetworkConnectivityServiceConnectionPolicyPscConnectionsErrorInfoList;
    get errorType(): string;
    get gceOperation(): string;
    get pscConnectionId(): string;
    get state(): string;
}
export declare class NetworkConnectivityServiceConnectionPolicyPscConnectionsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): NetworkConnectivityServiceConnectionPolicyPscConnectionsOutputReference;
}
export interface NetworkConnectivityServiceConnectionPolicyPscConfig {
    /**
    * Max number of PSC connections for this policy.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.21.0/docs/resources/network_connectivity_service_connection_policy#limit NetworkConnectivityServiceConnectionPolicy#limit}
    */
    readonly limit?: string;
    /**
    * IDs of the subnetworks or fully qualified identifiers for the subnetworks
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.21.0/docs/resources/network_connectivity_service_connection_policy#subnetworks NetworkConnectivityServiceConnectionPolicy#subnetworks}
    */
    readonly subnetworks: string[];
}
export declare function networkConnectivityServiceConnectionPolicyPscConfigToTerraform(struct?: NetworkConnectivityServiceConnectionPolicyPscConfigOutputReference | NetworkConnectivityServiceConnectionPolicyPscConfig): any;
export declare function networkConnectivityServiceConnectionPolicyPscConfigToHclTerraform(struct?: NetworkConnectivityServiceConnectionPolicyPscConfigOutputReference | NetworkConnectivityServiceConnectionPolicyPscConfig): any;
export declare class NetworkConnectivityServiceConnectionPolicyPscConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): NetworkConnectivityServiceConnectionPolicyPscConfig | undefined;
    set internalValue(value: NetworkConnectivityServiceConnectionPolicyPscConfig | undefined);
    private _limit?;
    get limit(): string;
    set limit(value: string);
    resetLimit(): void;
    get limitInput(): string | undefined;
    private _subnetworks?;
    get subnetworks(): string[];
    set subnetworks(value: string[]);
    get subnetworksInput(): string[] | undefined;
}
export interface NetworkConnectivityServiceConnectionPolicyTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.21.0/docs/resources/network_connectivity_service_connection_policy#create NetworkConnectivityServiceConnectionPolicy#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.21.0/docs/resources/network_connectivity_service_connection_policy#delete NetworkConnectivityServiceConnectionPolicy#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.21.0/docs/resources/network_connectivity_service_connection_policy#update NetworkConnectivityServiceConnectionPolicy#update}
    */
    readonly update?: string;
}
export declare function networkConnectivityServiceConnectionPolicyTimeoutsToTerraform(struct?: NetworkConnectivityServiceConnectionPolicyTimeouts | cdktf.IResolvable): any;
export declare function networkConnectivityServiceConnectionPolicyTimeoutsToHclTerraform(struct?: NetworkConnectivityServiceConnectionPolicyTimeouts | cdktf.IResolvable): any;
export declare class NetworkConnectivityServiceConnectionPolicyTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): NetworkConnectivityServiceConnectionPolicyTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: NetworkConnectivityServiceConnectionPolicyTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google/5.21.0/docs/resources/network_connectivity_service_connection_policy google_network_connectivity_service_connection_policy}
*/
export declare class NetworkConnectivityServiceConnectionPolicy extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_network_connectivity_service_connection_policy";
    /**
    * Generates CDKTF code for importing a NetworkConnectivityServiceConnectionPolicy resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the NetworkConnectivityServiceConnectionPolicy to import
    * @param importFromId The id of the existing NetworkConnectivityServiceConnectionPolicy that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google/5.21.0/docs/resources/network_connectivity_service_connection_policy#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the NetworkConnectivityServiceConnectionPolicy to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google/5.21.0/docs/resources/network_connectivity_service_connection_policy google_network_connectivity_service_connection_policy} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options NetworkConnectivityServiceConnectionPolicyConfig
    */
    constructor(scope: Construct, id: string, config: NetworkConnectivityServiceConnectionPolicyConfig);
    get createTime(): string;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _effectiveLabels;
    get effectiveLabels(): cdktf.StringMap;
    get etag(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get infrastructure(): string;
    private _labels?;
    get labels(): {
        [key: string]: string;
    };
    set labels(value: {
        [key: string]: string;
    });
    resetLabels(): void;
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    get locationInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _network?;
    get network(): string;
    set network(value: string);
    get networkInput(): string | undefined;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _pscConnections;
    get pscConnections(): NetworkConnectivityServiceConnectionPolicyPscConnectionsList;
    private _serviceClass?;
    get serviceClass(): string;
    set serviceClass(value: string);
    get serviceClassInput(): string | undefined;
    private _terraformLabels;
    get terraformLabels(): cdktf.StringMap;
    get updateTime(): string;
    private _pscConfig;
    get pscConfig(): NetworkConnectivityServiceConnectionPolicyPscConfigOutputReference;
    putPscConfig(value: NetworkConnectivityServiceConnectionPolicyPscConfig): void;
    resetPscConfig(): void;
    get pscConfigInput(): NetworkConnectivityServiceConnectionPolicyPscConfig | undefined;
    private _timeouts;
    get timeouts(): NetworkConnectivityServiceConnectionPolicyTimeoutsOutputReference;
    putTimeouts(value: NetworkConnectivityServiceConnectionPolicyTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | NetworkConnectivityServiceConnectionPolicyTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
