/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface SccFolderCustomModuleConfig extends cdktf.TerraformMetaArguments {
    /**
    * The display name of the Security Health Analytics custom module. This
    * display name becomes the finding category for all findings that are
    * returned by this custom module. The display name must be between 1 and
    * 128 characters, start with a lowercase letter, and contain alphanumeric
    * characters or underscores only.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.21.0/docs/resources/scc_folder_custom_module#display_name SccFolderCustomModule#display_name}
    */
    readonly displayName: string;
    /**
    * The enablement state of the custom module. Possible values: ["ENABLED", "DISABLED"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.21.0/docs/resources/scc_folder_custom_module#enablement_state SccFolderCustomModule#enablement_state}
    */
    readonly enablementState: string;
    /**
    * Numerical ID of the parent folder.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.21.0/docs/resources/scc_folder_custom_module#folder SccFolderCustomModule#folder}
    */
    readonly folder: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.21.0/docs/resources/scc_folder_custom_module#id SccFolderCustomModule#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * custom_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.21.0/docs/resources/scc_folder_custom_module#custom_config SccFolderCustomModule#custom_config}
    */
    readonly customConfig: SccFolderCustomModuleCustomConfig;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.21.0/docs/resources/scc_folder_custom_module#timeouts SccFolderCustomModule#timeouts}
    */
    readonly timeouts?: SccFolderCustomModuleTimeouts;
}
export interface SccFolderCustomModuleCustomConfigCustomOutputPropertiesValueExpression {
    /**
    * Description of the expression. This is a longer text which describes the
    * expression, e.g. when hovered over it in a UI.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.21.0/docs/resources/scc_folder_custom_module#description SccFolderCustomModule#description}
    */
    readonly description?: string;
    /**
    * Textual representation of an expression in Common Expression Language syntax.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.21.0/docs/resources/scc_folder_custom_module#expression SccFolderCustomModule#expression}
    */
    readonly expression: string;
    /**
    * String indicating the location of the expression for error reporting, e.g. a
    * file name and a position in the file.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.21.0/docs/resources/scc_folder_custom_module#location SccFolderCustomModule#location}
    */
    readonly location?: string;
    /**
    * Title for the expression, i.e. a short string describing its purpose. This can
    * be used e.g. in UIs which allow to enter the expression.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.21.0/docs/resources/scc_folder_custom_module#title SccFolderCustomModule#title}
    */
    readonly title?: string;
}
export declare function sccFolderCustomModuleCustomConfigCustomOutputPropertiesValueExpressionToTerraform(struct?: SccFolderCustomModuleCustomConfigCustomOutputPropertiesValueExpressionOutputReference | SccFolderCustomModuleCustomConfigCustomOutputPropertiesValueExpression): any;
export declare function sccFolderCustomModuleCustomConfigCustomOutputPropertiesValueExpressionToHclTerraform(struct?: SccFolderCustomModuleCustomConfigCustomOutputPropertiesValueExpressionOutputReference | SccFolderCustomModuleCustomConfigCustomOutputPropertiesValueExpression): any;
export declare class SccFolderCustomModuleCustomConfigCustomOutputPropertiesValueExpressionOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): SccFolderCustomModuleCustomConfigCustomOutputPropertiesValueExpression | undefined;
    set internalValue(value: SccFolderCustomModuleCustomConfigCustomOutputPropertiesValueExpression | undefined);
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _expression?;
    get expression(): string;
    set expression(value: string);
    get expressionInput(): string | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    resetLocation(): void;
    get locationInput(): string | undefined;
    private _title?;
    get title(): string;
    set title(value: string);
    resetTitle(): void;
    get titleInput(): string | undefined;
}
export interface SccFolderCustomModuleCustomConfigCustomOutputProperties {
    /**
    * Name of the property for the custom output.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.21.0/docs/resources/scc_folder_custom_module#name SccFolderCustomModule#name}
    */
    readonly name?: string;
    /**
    * value_expression block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.21.0/docs/resources/scc_folder_custom_module#value_expression SccFolderCustomModule#value_expression}
    */
    readonly valueExpression?: SccFolderCustomModuleCustomConfigCustomOutputPropertiesValueExpression;
}
export declare function sccFolderCustomModuleCustomConfigCustomOutputPropertiesToTerraform(struct?: SccFolderCustomModuleCustomConfigCustomOutputProperties | cdktf.IResolvable): any;
export declare function sccFolderCustomModuleCustomConfigCustomOutputPropertiesToHclTerraform(struct?: SccFolderCustomModuleCustomConfigCustomOutputProperties | cdktf.IResolvable): any;
export declare class SccFolderCustomModuleCustomConfigCustomOutputPropertiesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): SccFolderCustomModuleCustomConfigCustomOutputProperties | cdktf.IResolvable | undefined;
    set internalValue(value: SccFolderCustomModuleCustomConfigCustomOutputProperties | cdktf.IResolvable | undefined);
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
    private _valueExpression;
    get valueExpression(): SccFolderCustomModuleCustomConfigCustomOutputPropertiesValueExpressionOutputReference;
    putValueExpression(value: SccFolderCustomModuleCustomConfigCustomOutputPropertiesValueExpression): void;
    resetValueExpression(): void;
    get valueExpressionInput(): SccFolderCustomModuleCustomConfigCustomOutputPropertiesValueExpression | undefined;
}
export declare class SccFolderCustomModuleCustomConfigCustomOutputPropertiesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: SccFolderCustomModuleCustomConfigCustomOutputProperties[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): SccFolderCustomModuleCustomConfigCustomOutputPropertiesOutputReference;
}
export interface SccFolderCustomModuleCustomConfigCustomOutput {
    /**
    * properties block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.21.0/docs/resources/scc_folder_custom_module#properties SccFolderCustomModule#properties}
    */
    readonly properties?: SccFolderCustomModuleCustomConfigCustomOutputProperties[] | cdktf.IResolvable;
}
export declare function sccFolderCustomModuleCustomConfigCustomOutputToTerraform(struct?: SccFolderCustomModuleCustomConfigCustomOutputOutputReference | SccFolderCustomModuleCustomConfigCustomOutput): any;
export declare function sccFolderCustomModuleCustomConfigCustomOutputToHclTerraform(struct?: SccFolderCustomModuleCustomConfigCustomOutputOutputReference | SccFolderCustomModuleCustomConfigCustomOutput): any;
export declare class SccFolderCustomModuleCustomConfigCustomOutputOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): SccFolderCustomModuleCustomConfigCustomOutput | undefined;
    set internalValue(value: SccFolderCustomModuleCustomConfigCustomOutput | undefined);
    private _properties;
    get properties(): SccFolderCustomModuleCustomConfigCustomOutputPropertiesList;
    putProperties(value: SccFolderCustomModuleCustomConfigCustomOutputProperties[] | cdktf.IResolvable): void;
    resetProperties(): void;
    get propertiesInput(): cdktf.IResolvable | SccFolderCustomModuleCustomConfigCustomOutputProperties[] | undefined;
}
export interface SccFolderCustomModuleCustomConfigPredicate {
    /**
    * Description of the expression. This is a longer text which describes the
    * expression, e.g. when hovered over it in a UI.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.21.0/docs/resources/scc_folder_custom_module#description SccFolderCustomModule#description}
    */
    readonly description?: string;
    /**
    * Textual representation of an expression in Common Expression Language syntax.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.21.0/docs/resources/scc_folder_custom_module#expression SccFolderCustomModule#expression}
    */
    readonly expression: string;
    /**
    * String indicating the location of the expression for error reporting, e.g. a
    * file name and a position in the file.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.21.0/docs/resources/scc_folder_custom_module#location SccFolderCustomModule#location}
    */
    readonly location?: string;
    /**
    * Title for the expression, i.e. a short string describing its purpose. This can
    * be used e.g. in UIs which allow to enter the expression.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.21.0/docs/resources/scc_folder_custom_module#title SccFolderCustomModule#title}
    */
    readonly title?: string;
}
export declare function sccFolderCustomModuleCustomConfigPredicateToTerraform(struct?: SccFolderCustomModuleCustomConfigPredicateOutputReference | SccFolderCustomModuleCustomConfigPredicate): any;
export declare function sccFolderCustomModuleCustomConfigPredicateToHclTerraform(struct?: SccFolderCustomModuleCustomConfigPredicateOutputReference | SccFolderCustomModuleCustomConfigPredicate): any;
export declare class SccFolderCustomModuleCustomConfigPredicateOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): SccFolderCustomModuleCustomConfigPredicate | undefined;
    set internalValue(value: SccFolderCustomModuleCustomConfigPredicate | undefined);
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _expression?;
    get expression(): string;
    set expression(value: string);
    get expressionInput(): string | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    resetLocation(): void;
    get locationInput(): string | undefined;
    private _title?;
    get title(): string;
    set title(value: string);
    resetTitle(): void;
    get titleInput(): string | undefined;
}
export interface SccFolderCustomModuleCustomConfigResourceSelector {
    /**
    * The resource types to run the detector on.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.21.0/docs/resources/scc_folder_custom_module#resource_types SccFolderCustomModule#resource_types}
    */
    readonly resourceTypes: string[];
}
export declare function sccFolderCustomModuleCustomConfigResourceSelectorToTerraform(struct?: SccFolderCustomModuleCustomConfigResourceSelectorOutputReference | SccFolderCustomModuleCustomConfigResourceSelector): any;
export declare function sccFolderCustomModuleCustomConfigResourceSelectorToHclTerraform(struct?: SccFolderCustomModuleCustomConfigResourceSelectorOutputReference | SccFolderCustomModuleCustomConfigResourceSelector): any;
export declare class SccFolderCustomModuleCustomConfigResourceSelectorOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): SccFolderCustomModuleCustomConfigResourceSelector | undefined;
    set internalValue(value: SccFolderCustomModuleCustomConfigResourceSelector | undefined);
    private _resourceTypes?;
    get resourceTypes(): string[];
    set resourceTypes(value: string[]);
    get resourceTypesInput(): string[] | undefined;
}
export interface SccFolderCustomModuleCustomConfig {
    /**
    * Text that describes the vulnerability or misconfiguration that the custom
    * module detects. This explanation is returned with each finding instance to
    * help investigators understand the detected issue. The text must be enclosed in quotation marks.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.21.0/docs/resources/scc_folder_custom_module#description SccFolderCustomModule#description}
    */
    readonly description?: string;
    /**
    * An explanation of the recommended steps that security teams can take to resolve
    * the detected issue. This explanation is returned with each finding generated by
    * this module in the nextSteps property of the finding JSON.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.21.0/docs/resources/scc_folder_custom_module#recommendation SccFolderCustomModule#recommendation}
    */
    readonly recommendation: string;
    /**
    * The severity to assign to findings generated by the module. Possible values: ["CRITICAL", "HIGH", "MEDIUM", "LOW"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.21.0/docs/resources/scc_folder_custom_module#severity SccFolderCustomModule#severity}
    */
    readonly severity: string;
    /**
    * custom_output block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.21.0/docs/resources/scc_folder_custom_module#custom_output SccFolderCustomModule#custom_output}
    */
    readonly customOutput?: SccFolderCustomModuleCustomConfigCustomOutput;
    /**
    * predicate block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.21.0/docs/resources/scc_folder_custom_module#predicate SccFolderCustomModule#predicate}
    */
    readonly predicate: SccFolderCustomModuleCustomConfigPredicate;
    /**
    * resource_selector block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.21.0/docs/resources/scc_folder_custom_module#resource_selector SccFolderCustomModule#resource_selector}
    */
    readonly resourceSelector: SccFolderCustomModuleCustomConfigResourceSelector;
}
export declare function sccFolderCustomModuleCustomConfigToTerraform(struct?: SccFolderCustomModuleCustomConfigOutputReference | SccFolderCustomModuleCustomConfig): any;
export declare function sccFolderCustomModuleCustomConfigToHclTerraform(struct?: SccFolderCustomModuleCustomConfigOutputReference | SccFolderCustomModuleCustomConfig): any;
export declare class SccFolderCustomModuleCustomConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): SccFolderCustomModuleCustomConfig | undefined;
    set internalValue(value: SccFolderCustomModuleCustomConfig | undefined);
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _recommendation?;
    get recommendation(): string;
    set recommendation(value: string);
    get recommendationInput(): string | undefined;
    private _severity?;
    get severity(): string;
    set severity(value: string);
    get severityInput(): string | undefined;
    private _customOutput;
    get customOutput(): SccFolderCustomModuleCustomConfigCustomOutputOutputReference;
    putCustomOutput(value: SccFolderCustomModuleCustomConfigCustomOutput): void;
    resetCustomOutput(): void;
    get customOutputInput(): SccFolderCustomModuleCustomConfigCustomOutput | undefined;
    private _predicate;
    get predicate(): SccFolderCustomModuleCustomConfigPredicateOutputReference;
    putPredicate(value: SccFolderCustomModuleCustomConfigPredicate): void;
    get predicateInput(): SccFolderCustomModuleCustomConfigPredicate | undefined;
    private _resourceSelector;
    get resourceSelector(): SccFolderCustomModuleCustomConfigResourceSelectorOutputReference;
    putResourceSelector(value: SccFolderCustomModuleCustomConfigResourceSelector): void;
    get resourceSelectorInput(): SccFolderCustomModuleCustomConfigResourceSelector | undefined;
}
export interface SccFolderCustomModuleTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.21.0/docs/resources/scc_folder_custom_module#create SccFolderCustomModule#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.21.0/docs/resources/scc_folder_custom_module#delete SccFolderCustomModule#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.21.0/docs/resources/scc_folder_custom_module#update SccFolderCustomModule#update}
    */
    readonly update?: string;
}
export declare function sccFolderCustomModuleTimeoutsToTerraform(struct?: SccFolderCustomModuleTimeouts | cdktf.IResolvable): any;
export declare function sccFolderCustomModuleTimeoutsToHclTerraform(struct?: SccFolderCustomModuleTimeouts | cdktf.IResolvable): any;
export declare class SccFolderCustomModuleTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): SccFolderCustomModuleTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: SccFolderCustomModuleTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google/5.21.0/docs/resources/scc_folder_custom_module google_scc_folder_custom_module}
*/
export declare class SccFolderCustomModule extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_scc_folder_custom_module";
    /**
    * Generates CDKTF code for importing a SccFolderCustomModule resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the SccFolderCustomModule to import
    * @param importFromId The id of the existing SccFolderCustomModule that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google/5.21.0/docs/resources/scc_folder_custom_module#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the SccFolderCustomModule to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google/5.21.0/docs/resources/scc_folder_custom_module google_scc_folder_custom_module} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options SccFolderCustomModuleConfig
    */
    constructor(scope: Construct, id: string, config: SccFolderCustomModuleConfig);
    get ancestorModule(): string;
    private _displayName?;
    get displayName(): string;
    set displayName(value: string);
    get displayNameInput(): string | undefined;
    private _enablementState?;
    get enablementState(): string;
    set enablementState(value: string);
    get enablementStateInput(): string | undefined;
    private _folder?;
    get folder(): string;
    set folder(value: string);
    get folderInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get lastEditor(): string;
    get name(): string;
    get updateTime(): string;
    private _customConfig;
    get customConfig(): SccFolderCustomModuleCustomConfigOutputReference;
    putCustomConfig(value: SccFolderCustomModuleCustomConfig): void;
    get customConfigInput(): SccFolderCustomModuleCustomConfig | undefined;
    private _timeouts;
    get timeouts(): SccFolderCustomModuleTimeoutsOutputReference;
    putTimeouts(value: SccFolderCustomModuleTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | SccFolderCustomModuleTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
